@@ -23,10 +23,10 @@
 #define FILECHOOSEWIDGET_H
 
 #include <QWidget>
+#include <QSettings>
 
 #include <dlinkbutton.h>
 
-class QPushButton;
 class FileChooseWidget : public QWidget
 {
     Q_OBJECT
@@ -42,6 +42,7 @@ private slots:
 
 private:
     Dtk::Widget::DLinkButton *m_fileChooseBtn;
+    QSettings m_settings;
 };
 
 #endif // FILECHOOSEWIDGET_H
