@@ -50,7 +50,7 @@ int main(int argc, char *argv[])
 //    app.loadTranslator(QList<QLocale>() << QLocale("zh_CN"));
     app.loadTranslator();
     app.setProductName(QApplication::translate("main", "Deepin Package Manager"));
-    app.setApplicationDescription(QApplication::translate("main", "Deepin Package Manager is an application used to help users install and remove local software, supports bulk install."));
+    app.setApplicationDescription(QApplication::translate("main", "Deepin Package Manager is used to help users install and remove local packages, supporting bulk install."));
 
     DLogManager::registerConsoleAppender();
     DLogManager::registerFileAppender();
