@@ -3,7 +3,7 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
+        <source>Dark theme</source>
         <translation>Mørkt tema</translation>
     </message>
     <message>
@@ -222,7 +222,7 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
         <translation>Er du sikker på, at du vil afinstallere %1?
 Alle afhængigheder vil også blive fjernet</translation>
@@ -237,8 +237,8 @@ Alle afhængigheder vil også blive fjernet</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Deepin pakkehåndtering er et program som hjælper brugere med at installere og fjerne lokal software og som understøtter masseinstallation.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Deepin pakkehåndtering bruges til at hjælpe brugere med at installere og fjerne lokal pakke, med understøttelse af masseinstallation.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
