@@ -3,8 +3,8 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
-        <translation>Dunkles Theme</translation>
+        <source>Dark theme</source>
+        <translation>Dunkles Thema</translation>
     </message>
     <message>
         <location filename="../debinstaller.cpp" line="88"/>
@@ -222,9 +222,10 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
-        <translation>Sind Sie sicher, dass Sie %1 deinstallieren möchten? Alle Abhängigkeiten werden ebenfalls deinstalliert</translation>
+        <translation>Möchten Sie %1 wirklich deinstallieren?
+Alle Abhängigkeiten werden ebenfalls entfernt</translation>
     </message>
 </context>
 <context>
@@ -236,8 +237,8 @@ All dependencies will also be removed</source>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Deepin Package Manager ist eine Anwendung, die Benutzern beim installieren und entfernen von Softwarepaketen hilft und Installationen mit Stapelverarbeitung unterstützt.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Deepin Package Manager wird verwendet, um Benutzer bei der Installation und Entfernung von lokalen Paketen zu unterstützen, er unterstützt die Masseninstallation.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
