@@ -3,8 +3,8 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
-        <translation>Thème foncé</translation>
+        <source>Dark theme</source>
+        <translation>Thème sombre</translation>
     </message>
     <message>
         <location filename="../debinstaller.cpp" line="88"/>
@@ -43,7 +43,7 @@
         <location filename="../deblistmodel.cpp" line="296"/>
         <location filename="../deblistmodel.cpp" line="303"/>
         <source>Broken Dependencies: %1</source>
-        <translation>Dépendances cassées: : %1</translation>
+        <translation>Dépendances cassées : %1</translation>
     </message>
     <message>
         <location filename="../deblistmodel.cpp" line="299"/>
@@ -222,10 +222,10 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
-        <translation>Souhaitez-vous vraiment désinstaller %1 ?
-Toutes les dépendances seront également supprimées</translation>
+        <translation>Êtes-vous sûr de vouloir désinstaller %1 ?
+Toutes les dépendances seront également supprimées.</translation>
     </message>
 </context>
 <context>
@@ -237,8 +237,8 @@ Toutes les dépendances seront également supprimées</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Le Gestionnaire de Paquets de Deepin est une application pour aider les utilisateurs à gérer les logiciels installés, il supporte également l&apos;installation multiple.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Deepin Package Manager est utilisé pour aider les utilisateurs à installer et à supprimer des paquets locaux, il supporte l&apos;installation multiple.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
