@@ -3,7 +3,7 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
+        <source>Dark theme</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -222,10 +222,9 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
-        <translation>Jeste li sigurni da želite deinstalirati %1?
-Sve zavisnosti će također biti uklonjene</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -237,8 +236,8 @@ Sve zavisnosti će također biti uklonjene</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Deepin upravitelj paketima je aplikacija koja služi korisnicima da instaliraju i uklone lokalni software, podržavajući skupno instaliranje</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
