@@ -3,8 +3,8 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
-        <translation>Tema Gelap</translation>
+        <source>Dark theme</source>
+        <translation>Tema gelap</translation>
     </message>
     <message>
         <location filename="../debinstaller.cpp" line="88"/>
@@ -222,7 +222,7 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
         <translation>Anda pasti mahu menyahpasang %1?
 Semua dependensinya juga akan dibuang</translation>
@@ -237,8 +237,8 @@ Semua dependensinya juga akan dibuang</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Pengurus Pakej Deepin ialah aplikasi yang digunakan untuk membantu pengguna memasang dan membuang perisian setempat, selain itu ia menyokong pemasangan secara pukal.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Pengurus Pakej Deepin digunakan untuk bantu pengguna memasang dan membuang perisian setempat, selain itu ia menyokong pemasangan secara pukal.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
