@@ -3,7 +3,7 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
+        <source>Dark theme</source>
         <translation>Ciemny motyw</translation>
     </message>
     <message>
@@ -222,10 +222,10 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
-        <translation>Czy na pewno chcesz odinstalować %1?
-Zostaną usunięte również wszystkie zależności.</translation>
+        <translation>Czy na pewno chcesz odinstalować %1? 
+Wszystkie zależności zostaną również usunięte</translation>
     </message>
 </context>
 <context>
@@ -237,8 +237,8 @@ Zostaną usunięte również wszystkie zależności.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Zarządzanie pakietami Deepin to program, który pomaga użytkownikom instalować i usuwać lokalne oprogramowanie, obsługuje instalację zbiorczą.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Deepin Package Manager służy do pomocy użytkownikom w instalowaniu i usuwaniu lokalnych pakietów, wspierając instalację zbiorczą.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
