@@ -3,8 +3,8 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
-        <translation>Темная Тема</translation>
+        <source>Dark theme</source>
+        <translation>Темная тема</translation>
     </message>
     <message>
         <location filename="../debinstaller.cpp" line="88"/>
@@ -222,7 +222,7 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
         <translation>Вы действительно хотите удалить %1?
 Все зависимости также будут удалены.</translation>
@@ -237,8 +237,8 @@ All dependencies will also be removed</source>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Менеджер Пакетов Deepin используется для помощи пользователям в установке и удалении программного обеспечения, с поддержкой массовой установки.</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Менеджер Пакетов Deepin используется, чтобы помочь пользователям устанавливать и удалять локальные пакеты, поддерживая массовую установку.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
