@@ -3,7 +3,7 @@
     <name>DebInstaller</name>
     <message>
         <location filename="../debinstaller.cpp" line="62"/>
-        <source>Dark Theme</source>
+        <source>Dark theme</source>
         <translation>暗色主題</translation>
     </message>
     <message>
@@ -222,10 +222,10 @@
     </message>
     <message>
         <location filename="../uninstallconfirmpage.cpp" line="101"/>
-        <source>Are you sure to uninstall %1?
+        <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
         <translation>確定解除安裝 %1？
-所有依賴的軟體也會移除</translation>
+也會移除所有依賴</translation>
     </message>
 </context>
 <context>
@@ -237,8 +237,8 @@ All dependencies will also be removed</source>
     </message>
     <message>
         <location filename="../main.cpp" line="53"/>
-        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
-        <translation>Deepin 軟體包管理器能協助使用者安裝與移除電腦上的軟體。支援批次安裝。</translation>
+        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
+        <translation>Deepin 軟體包管理器用來協助使用者安裝及移除本機軟體包，支援批次安裝。</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
